==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/eo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="eo">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elekti unu aŭ pliajn aparatojn</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Ŝanĝi al fenestro</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Eniri plenekranan reĝimon</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elektu unu aŭ pliajn aparatojn</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Helpo</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Ne eblis trovi dosieradministrilon.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instalu dosieradministrilon.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Averto</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>La ekranregistrado ne startis: mankas libera diskospaco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Atingis la limon de libera diskospaco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limo de libera diskospaco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajto</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>La ekranregistrado ĉesis: mankas libera diskospaco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Plenekrane</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenestro</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ne eblis trovi dosieradministrilon.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instalu dosieradministrilon.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Fontkodo</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Ĉefpaĝo</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tradukoj</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donacu</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elektu unu aŭ pliajn aparatojn</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Ekranregiono</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Komenci</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Daŭrigi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Eliri</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ekranopligrandigo</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Komenci</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Daŭrigi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Eliri</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Inversigi horizontale</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Inversigi kapo-suben</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inversigi kolorojn</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grize</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Nigre-blanke</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Forigi kadron de fenestro</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160×120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320×240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Agordoj de kamerao</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640×480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Ekranregiono</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restarigi</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ekranopligrandigo</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Ĝisnombrado</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Grando de la video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Libera diskospaco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informoj</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de registrado:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Aŭdaĵoj</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Filmeroj</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Filmkodeko</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Aŭdviduja formo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Sonkodeko</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalito</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne ekranregistri musmontrilon</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Horo</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Lanĉi tempumilon</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Ĉesi registradon post</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horoj</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutoj</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundoj</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Dosierindiko de filmregistraĵo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limo de libera diskospaco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Montri je taskopleto</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekundoj da atendado antaŭ ekregistri</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Serĉi ĝisdatigojn</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Helpo</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Filmetformo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponebla</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ne disponebla</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Komenci</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Daŭrigi</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Ludi</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Dosierujo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inversigi kolorojn</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grize</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Sendi prikolapsan raporton</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl + Shift + F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl + Shift + F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl + Shift + F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Ludi lastan registron</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Malfermi dosierujon</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl + Shift + F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimumigi kiam registrado startos</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starti minimumigite</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Inversigi horizontale</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Inversigi kapo-suben</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Nigre-blanke</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Forigi kadron de fenestro</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donacu</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restarigi ĉiujn agordojn dum proksima starto</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Aŭtorrajtoj kaj kopirajtaj permesiloj de la bildoj</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajto</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Ekranregistrado</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Ludilo</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Protokolo</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Aŭtorrajtoj kaj kopirajtaj permesiloj de la bildoj</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Ludi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plenekrane</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Antaŭa filmero</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Sekva filmero</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silentigi</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Movi menuon</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/eo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="eo">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elekti unu aŭ pliajn aparatojn</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Ŝanĝi al fenestro</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Eniri plenekranan reĝimon</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elektu unu aŭ pliajn aparatojn</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Helpo</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Ne eblis trovi dosieradministrilon.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instalu dosieradministrilon.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Averto</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>La ekranregistrado ne startis: mankas libera diskospaco.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Atingis la limon de libera diskospaco.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limo de libera diskospaco</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajto</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>La ekranregistrado ĉesis: mankas libera diskospaco.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Plenekrane</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fenestro</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Ne eblis trovi dosieradministrilon.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Instalu dosieradministrilon.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Fontkodo</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Ĉefpaĝo</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tradukoj</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donacu</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Elektu unu aŭ pliajn aparatojn</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Ekranregiono</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Ekranregiono</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Komenci</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Daŭrigi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Eliri</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ekranopligrandigo</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Komenci</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Daŭrigi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Eliri</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ekranopligrandigo</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialogo</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Inversigi horizontale</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Inversigi kapo-suben</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inversigi kolorojn</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grize</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Nigre-blanke</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Forigi kadron de fenestro</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Agordoj de kamerao</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Ekranregiono</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Restarigi</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ekranopligrandigo</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Ĝisnombrado</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Grando de la video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Libera diskospaco:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informoj</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tempo de registrado:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Aŭdaĵoj</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Filmeroj</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Filmkodeko</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Aŭdviduja formo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Sonkodeko</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalito</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne ekranregistri musmontrilon</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Horo</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuto</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Lanĉi tempumilon</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Ĉesi registradon post</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Horoj</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutoj</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekundoj</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Dosierindiko de filmregistraĵo</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limo de libera diskospaco</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Montri je taskopleto</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekundoj da atendado antaŭ ekregistri</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Serĉi ĝisdatigojn</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Helpo</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Filmetformo</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponebla</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ne disponebla</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Komenci</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Daŭrigi</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Ludi</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Dosierujo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamerao</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inversigi kolorojn</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grize</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Sendi prikolapsan raporton</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>Ctrl + Shift + F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>Ctrl + Shift + F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>Ctrl + Shift + F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Ludi lastan registron</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Malfermi dosierujon</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>Ctrl + Shift + F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimumigi kiam registrado startos</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starti minimumigite</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Inversigi horizontale</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Inversigi kapo-suben</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Nigre-blanke</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Forigi kadron de fenestro</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donacu</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Restarigi ĉiujn agordojn dum proksima starto</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Aŭtorrajtoj kaj kopirajtaj permesiloj de la bildoj</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajto</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Ekranregistrado</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Ludilo</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Protokolo</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ON</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Aŭtorrajtoj kaj kopirajtaj permesiloj de la bildoj</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Ludi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paŭzigi</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Haltigi</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plenekrane</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Antaŭa filmero</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Sekva filmero</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silentigi</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Movi menuon</translation>
    </message>
</context>
</TS>
